%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Name:		gausssum
Version:	2.2.6
Release:	1%{?dist}
Summary:	A GUI application for analysis of output of quantum computations
Group:		Applications/Engineering
License:	GPLv2+
URL:		http://gausssum.sourceforge.net/
Source0:	http://downloads.sourceforge.net/%{name}/GaussSum-%{version}.tar.gz
Source1:	gausssum.desktop
# Patch to use system python-cclib instead of own copy
Patch0:		gausssum-cclib.patch
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildArch:	noarch

# For converting .ico into .png
BuildRequires:	ImageMagick
BuildRequires:	desktop-file-utils
# We need this for python_sitelib to make sense
BuildRequires:	python-devel

Requires:	gnuplot
Requires:	numpy
Requires:	python-cclib
Requires:	python-imaging-tk

%description
GaussSum is a GUI application that can analyze the output of ADF, GAMESS (US),
GAMESS-UK, Gaussian, Jaguar and PC GAMESS to extract and calculate useful
information. This includes the progress of the SCF cycles, geometry
optimization, UV-Vis/IR/Raman spectra, MO levels, MO contributions and more.

%prep
%setup -q -n GaussSum-%{version}
%patch0 -p1 -b .cclib

# Change location of documentation
sed 's|os.path.join(installlocation,"Docs","index.html")|"%{_docdir}/%{name}-%{version}/Docs/index.html"|g' \
 gausssum/gausssumgui.py > gausssum/gausssumgui.py.new && \
touch -r gausssum/gausssumgui.py gausssum/gausssumgui.py.new && \
mv gausssum/gausssumgui.py.new gausssum/gausssumgui.py

# Fix gnuplot location
sed 's|os.path.join(installlocation,"gnuplot400","bin","wgnuplot.exe")|"%{_bindir}/gnuplot"|g' \
  gausssum/gausssumgui.py > gausssum/gausssumgui.py.new && \
touch -r gausssum/gausssumgui.py gausssum/gausssumgui.py.new && \
mv gausssum/gausssumgui.py.new gausssum/gausssumgui.py


# Fix end of line encodings
for file in Docs/style.css gausssum/*.py gausssum/cclib/*.py; do
 sed -e 's|\r||g' $file > $file.new && \
 touch -r $file $file.new && \
 mv $file.new $file
done

# Fix attributes
find gausssum/ -name "*.py" -exec chmod 644 {} \;
chmod 644 Docs/mesh.gif Docs/style.css

# Convert icon into png
convert GaussSum.ico GaussSum.png

# Remove integrated cclib
rm -rf gausssum/cclib

%build

%install
rm -rf %{buildroot} 
mkdir -p %{buildroot}%{python_sitelib}
# Install python library
cp -a %{name} %{buildroot}%{python_sitelib}
# Install python executable itself
install -D -p -m 755 GaussSum.py %{buildroot}%{_bindir}/GaussSum.py
# Install icon
install -D -p -m 644 GaussSum.png %{buildroot}%{_datadir}/pixmaps/GaussSum.png
# Install desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

%clean
rm -rf %{buildroot} 

%files
%defattr(-,root,root,-)
%doc Docs/
%{_bindir}/GaussSum.py
%{python_sitelib}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/GaussSum.png
# Older rpm versions generate compiled Python objects in bindir
%if 0%{?fedora} < 11
%exclude %{_bindir}/GaussSum.pyc
%exclude %{_bindir}/GaussSum.pyo
%endif

%changelog
* Mon Feb 18 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 2.2.6-1
- Update to 2.2.6.

* Mon Feb  4 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 2.2.5-4
- Add patch for python-pillow compatibility

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Apr 25 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.5-1
- Update to 2.2.5.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Aug 6 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.4-1
- Update to 2.2.4.

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Feb 19 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.3-1
- Update to 2.2.3.

* Fri Jan 1 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.2-1
- Update to 2.2.2.

* Sun Dec 27 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.0-2
- Bump release.

* Sun Dec 27 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.2.0-1
- Update to 2.2.0.

* Fri Jul 31 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-5
- Fix a rather nasty packaging bug, BZ #514820 arising from missing
  BR: python-devel causing library to be placed in / instead of Python library.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 03 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-3
- Final review fixes.

* Sun May 03 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-2
- Review fixes.

* Wed Apr 29 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.1.6-1
- First release.
